pub struct LotteryChoice {
pub name: String,
pub reset: u64,
pub tickets: u64,
pub weight: u64,
}Expand description
Represents an individual choice for the lottery model.
Attributes
Fields
name: StringThe name of the choice
reset: u64How many tickets the choice should be reset to when it is chosen.
tickets: u64The current number of tickets the choice has.
weight: u64The number of tickets that will be added to tickets each time this choice is not picked.